/****************************************************************************
 *   $Id:: i2cmst.c 6097 2011-01-07 04:31:25Z nxp12832                      $
 *   Project: NXP LPC17xx I2C example
 *
 *   Description:
 *     This file contains I2C test modules, main entry, to test I2C APIs.
 *
 ****************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * NXP Semiconductors assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. NXP Semiconductors
 * reserves the right to make changes in the software without
 * notification. NXP Semiconductors also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
****************************************************************************/
#include "lpc17xx.h"
#include "type.h"
#include "i2c.h"

extern volatile uint8_t I2CMasterBuffer[I2C_PORT_NUM][BUFSIZE];
extern volatile uint8_t I2CSlaveBuffer[I2C_PORT_NUM][BUFSIZE];
extern volatile uint32_t I2CReadLength[I2C_PORT_NUM];
extern volatile uint32_t I2CWriteLength[I2C_PORT_NUM];

#define PORT_USED		1

/*******************************************************************************
**   Main Function  main()
*******************************************************************************/
int main (void)
{
  uint32_t i;
  const unsigned char * pic;
  const unsigned char qweqwe[512] = {  
    0 , 16 , 16 , 16 ,240 , 16 , 16 ,  0 ,  0 ,240 
 ,  0 ,  0 ,240 , 16 , 16 , 16 , 16 ,  0 ,  0 , 16 
 , 16 , 16 , 16 ,224 ,  0 ,  0 , 32 , 16 , 16 , 16 
 ,224 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 
 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 
 ,  0 ,254 ,254 ,254 , 14 , 14 , 14 , 14 , 14 , 14 
 ,142 ,142 ,142 ,254 ,254 ,254 , 64 , 64 , 32 , 32 
 , 32 , 32 , 32 , 32 , 32 , 32 , 32 , 16 , 16 ,144 
 ,144 ,144 ,144 , 80 , 80 , 80 , 48 , 48 , 48 , 16 
 , 16 , 16 , 16 , 24 , 24 , 24 , 20 , 20 , 20 , 20 
 , 18 , 18 , 28 , 16 , 48 ,208 , 32 , 32 , 32 , 32 
 , 32 , 32 , 32 , 32 , 32 , 64 , 64 , 64 , 64 , 64 
 ,128 ,128 ,128 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 
 ,  0 ,  0 , 63 ,  0 ,  0 ,  0 ,  0 , 63 ,  0 ,  0 
 , 31 , 32 , 32 , 32 , 32 ,  0 ,  0 , 32 , 33 , 33 
 , 33 , 30 ,  0 ,  0 , 32 , 56 , 38 , 35 , 32 ,  0 
 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 
 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,255 
 ,255 ,255 ,224 ,224 ,224 ,224 ,226 ,229 ,232 ,232 
 ,232 ,255 ,255 ,255 , 16 , 16 , 32 , 32 , 32 , 32 
 , 32 , 32 , 32 , 32 , 32 , 67 , 67 , 66 , 68 , 68 
 , 68 , 68 , 72 , 72 , 72 , 72 , 80 , 80 , 80 , 80 
 , 96 , 96 , 96 , 96 , 64 , 64 , 64 , 64 ,192 ,192 
 ,192 ,192 , 64 , 64 , 33 , 38 , 40 , 48 , 96 ,160 
 , 32 , 32 , 32 , 16 , 16 , 16 , 16 , 16 ,  8 ,  8 
 ,  8 ,  5 ,  2 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,128 
 ,252 ,  4 ,  4 ,252 ,  0 ,  0 ,  0 ,224 , 32 , 32 
 , 32 ,224 ,  0 ,  0 ,192 , 32 , 32 , 32 ,224 ,  0 
 ,  0 ,224 ,  4 ,  4 ,  4 ,224 ,  0 ,  0 ,252 , 36 
 , 52 , 40 ,224 ,  0 ,  0 ,192 , 32 , 32 , 32 ,224 
 ,  0 ,  0 ,224 , 32 , 32 , 32 ,224 ,  0 ,  0 ,  0 
 ,  0 ,  0 ,  0 ,  0 ,  0 ,252 ,132 ,132 ,132 ,132 
 ,124 ,  0 ,  0 ,252 ,  4 ,  4 ,  4 ,  4 ,  0 ,  0 
 ,252 , 68 , 68 , 68 , 68 ,  0 ,  0 ,128 ,252 , 68 
 , 68 ,108 ,152 ,  0 ,  0 ,124 , 68 , 68 , 68 ,132 
 ,  0 ,  0 ,  4 , 68 , 68 , 68 ,184 ,  0 ,  0 , 16 
 ,  9 ,253 ,  1 ,  1 ,  2 ,  2 ,  2 ,  2 ,  7 ,  4 
 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 
 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 , 24 , 15 ,  8 ,  8 
 ,  8 , 15 , 24 ,  0 ,  0 ,127 ,  8 ,  8 ,  8 ,  7 
 ,  0 ,  0 ,  7 ,  8 ,  8 ,  8 ,  7 ,  8 ,  0 ,  7 
 ,  8 ,  8 ,  8 , 15 ,  0 ,  0 ,  7 ,  8 ,  8 ,  8 
 ,  7 ,  0 ,  0 ,  7 ,  9 ,  9 ,  9 ,  9 ,  0 ,  0 
 ,127 ,  8 ,  8 ,  8 ,  7 ,  0 ,  0 ,  0 ,  0 ,  0 
 ,  0 ,  0 ,  0 , 15 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 
 ,  0 ,  7 ,  8 ,  8 ,  8 ,  8 ,  0 ,  0 , 15 ,  0 
 ,  0 ,  0 ,  0 ,  0 ,  0 ,  7 , 12 ,  8 ,  8 , 12 
 ,  7 ,  0 ,  0 ,  8 ,  8 ,  8 ,  8 ,  7 ,  0 ,  0 
 ,  8 ,  8 ,  8 ,  8 ,  7 ,  0 ,  0 ,  0 ,  0 , 15 
 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 
 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 ,  0 
 ,  0 ,  0 
 }; 

  /* SystemClockUpdate() updates the SystemFrequency variable */
  SystemClockUpdate();

  I2C0Init( );			/* initialize I2c0 */
  I2C1Init( );			/* initialize I2c1 */
  I2C2Init( );			/* initialize I2c2 */

  /* In order to start the I2CEngine, the all the parameters 
  must be set in advance, including I2CWriteLength, I2CReadLength,
  I2CCmd, and the I2cMasterBuffer which contains the stream
  command/data to the I2c slave device. 
  (1) If it's a I2C write only, the number of bytes to be written is 
  I2CWriteLength, I2CReadLength is zero, the content will be filled 
  in the I2CMasterBuffer. 
  (2) If it's a I2C read only, the number of bytes to be read is 
  I2CReadLength, I2CWriteLength is 0, the read value will be filled 
  in the I2CMasterBuffer. 
  (3) If it's a I2C Write/Read with repeated start, specify the 
  I2CWriteLength, fill the content of bytes to be written in 
  I2CMasterBuffer, specify the I2CReadLength, after the repeated 
  start and the device address with RD bit set, the content of the 
  reading will be filled in I2CMasterBuffer index at 
  I2CMasterBuffer[I2CWriteLength+2]. 
  
  e.g. Start, DevAddr(W), WRByte1...WRByteN, Repeated-Start, DevAddr(R), 
  RDByte1...RDByteN Stop. The content of the reading will be filled 
  after (I2CWriteLength + two devaddr) bytes. */

  /* Write SLA(W), address and one data byte */
  for(;;)
  {
  I2CStart(PORT_USED);
  I2CWriteLength[PORT_USED] = 700;
  I2CReadLength[PORT_USED] = 0;
  I2CMasterBuffer[PORT_USED][0] = PCF8594_ADDR;
  I2CMasterBuffer[PORT_USED][1] = 0x00;		/* address */
  
  I2CMasterBuffer[PORT_USED][2] = 0x80;
  I2CMasterBuffer[PORT_USED][3] = 0x01;       //   
  I2CMasterBuffer[PORT_USED][4] = 0x80;
  I2CMasterBuffer[PORT_USED][5] = 0x20; // Enable chip, 
  I2CMasterBuffer[PORT_USED][6] = 0x80;
  I2CMasterBuffer[PORT_USED][7] = 0x09; // page select 
  I2CMasterBuffer[PORT_USED][8] = 0x80;
  I2CMasterBuffer[PORT_USED][9] = 0x0C; // Display Mode: NORMAL 
  I2CMasterBuffer[PORT_USED][10] = 0x80;
  I2CMasterBuffer[PORT_USED][11] = 0x05; // MUX-rate: 1/34 
  I2CMasterBuffer[PORT_USED][12] = 0x80;
  I2CMasterBuffer[PORT_USED][13] = 0x14; // Bias system: 3 
  I2CMasterBuffer[PORT_USED][14] = 0x80;
  I2CMasterBuffer[PORT_USED][15] = 0x01;       //   
  I2CMasterBuffer[PORT_USED][16] = 0x80;
  I2CMasterBuffer[PORT_USED][17] = 0x0A; // page select 
  I2CMasterBuffer[PORT_USED][18] = 0x80;
  I2CMasterBuffer[PORT_USED][19] = 0x0A; // voltage multiplication factor: 2*V 
  I2CMasterBuffer[PORT_USED][20] = 0x80;
  I2CMasterBuffer[PORT_USED][21] = 0x20; // temperature coefficient: 0 
  I2CMasterBuffer[PORT_USED][22] = 0x80;
  I2CMasterBuffer[PORT_USED][23] = 0x05; // Vlcd - LOW; Voltage multiplier ON 
  I2CMasterBuffer[PORT_USED][24] = 0x80;
  I2CMasterBuffer[PORT_USED][25] = 0xC4; // Vlcd set 
  I2CEngine( PORT_USED );
  I2CStop(PORT_USED);

  I2CStart(PORT_USED); 
  I2CWriteLength[PORT_USED] = 700;
  I2CReadLength[PORT_USED] = 0;
  I2CMasterBuffer[PORT_USED][0] = PCF8594_ADDR;
  I2CMasterBuffer[PORT_USED][1]	= 0x40;
  
  for(i = 2; i < 642; i++) 
     I2CMasterBuffer[PORT_USED][i] = 0x00; 
  I2CEngine( PORT_USED );
  I2CStop(PORT_USED);
  
  
  /* ---------------------------------------------------------------    
         *         
         * --------------------------------------------------------------- */ 
   pic = qweqwe; 
   I2CStart(PORT_USED); 
   I2CWriteLength[PORT_USED] = 7;
   I2CReadLength[PORT_USED] = 0;
   I2CMasterBuffer[PORT_USED][0] = PCF8594_ADDR; 
   I2CMasterBuffer[PORT_USED][1] = 0x80;
   I2CMasterBuffer[PORT_USED][2] = 0x01;       //   
   I2CMasterBuffer[PORT_USED][3] = 0x80; 
   I2CMasterBuffer[PORT_USED][4] = 0x40; // set Y-
   I2CMasterBuffer[PORT_USED][5] = 0x80; 
   I2CMasterBuffer[PORT_USED][6] = 0x80; // set X-
   I2CEngine( PORT_USED );
   I2CStop(PORT_USED); 

   I2CStart(PORT_USED); 
   I2CWriteLength[PORT_USED] = 700;
   I2CReadLength[PORT_USED] = 0; 
   I2CMasterBuffer[PORT_USED][0] = PCF8594_ADDR;
   I2CMasterBuffer[PORT_USED][1] = 0x40;
   
   for(i = 2; i < 642; i++) 
      if (i < 514) 
	    I2CMasterBuffer[PORT_USED][i] = *(pic + i); 
      else
	      I2CMasterBuffer[PORT_USED][i] = 0x00; 
   I2CEngine( PORT_USED );
   I2CStop(PORT_USED); 	

  }


  /* Be careful with below fixed delay. From device to device, or
  even same device with different write length, or various I2C clock, 
  below delay length may need to be changed accordingly. Having 
  a break point before Write/Read start will be helpful to isolate 
  the problem. */
//  for ( i = 0; i < 0x200000; i++ );	/* Delay after write */
//
//  for ( i = 0; i < BUFSIZE; i++ )
//  {
//	I2CSlaveBuffer[PORT_USED][i] = 0x00;
//  }
//  /* Write SLA(W), address, SLA(R), and read one byte back. */
//  I2CWriteLength[PORT_USED] = 2;
//  I2CReadLength[PORT_USED] = 0;
//  I2CMasterBuffer[PORT_USED][0] = PCF8594_ADDR;
//  I2CMasterBuffer[PORT_USED][1] = 0x00;		/* address */
//  I2CMasterBuffer[PORT_USED][2] = PCF8594_ADDR | RD_BIT;
//  I2CEngine( PORT_USED );
//
//  /* Check the content of the Master and slave buffer */
//  while ( 1 );

}

/******************************************************************************
**                            End Of File
******************************************************************************/
